@@ -40,8 +40,8 @@ class QtGLWidget_Viewer3(QtOpenGL.QGLWidget):
         width = max(2, width)
         height = max(2, height)
         self.ctx.viewport = (0, 0, width, height)
-        self.nav.win_height = height
-        self.nav.win_width = width
+        self.nav.win_height = self.height()
+        self.nav.win_width = self.width()
 
     def mousePressEvent(self, event):
         self.nav.update_cursor_position(event.pos().x(), event.pos().y())
